;--------------------------------
;Defines

!define VERSION_MAJOR 1 
!define VERSION_MINOR 0.0
!define VERSION_POSTFIX_FULL ""
!ifdef WIN64
!ifdef IA64
!define VERSION_SYS_POSTFIX_FULL " for Windows IA-64"
!else
!define VERSION_SYS_POSTFIX_FULL " for Windows x64"
!endif
!else
!define VERSION_SYS_POSTFIX_FULL ""
!endif
!define NAME_FULL "UnZipper ${VERSION_MAJOR}.${VERSION_MINOR}${VERSION_POSTFIX_FULL}${VERSION_SYS_POSTFIX_FULL}"
!define VERSION_POSTFIX ""
!ifdef WIN64
!ifdef IA64
!define VERSION_SYS_POSTFIX "-ia64"
!else
!define VERSION_SYS_POSTFIX "-x64"
!endif
!else
!define VERSION_SYS_POSTFIX ""
!endif



!define FM_LINK "UnZipper File Manager.lnk"
!define HELP_LINK "UnZipper Help.lnk"

!define CLSID_CONTEXT_MENU {73950f91-2061-4ea3-8bd5-49ec4bf08ac2}

#!define NO_COMPRESSION

  !include "Library.nsh"
  !include "MUI.nsh"

;--------------------------------
;Configuration

  ;General
  Name "${NAME_FULL}"
  BrandingText "www.unzipper.com"
  OutFile "UnZipper${VERSION_MAJOR}.${VERSION_MINOR}${VERSION_POSTFIX}${VERSION_SYS_POSTFIX}.exe"
  Icon "7zipLogo.ico"
  UninstallIcon "7zipLogo.ico"
  !define MUI_ICON "7zipLogo.ico"

  ;Folder selection page
  InstallDir "$PROGRAMFILES\UnZipper"
  
  ;Get install folder from registry if available
  InstallDirRegKey HKLM "Software\UnZipper" "Path"

  ;Compressor
!ifndef NO_COMPRESSION
  SetCompressor /solid lzma
  ; SetCompressorFilter 1
!ifdef IA64
  SetCompressorDictSize 8
!else
  SetCompressorDictSize 4
!endif
!else
  SetCompress off
!endif


;--------------------------------
;Variables

;--------------------------------
;Interface Settings

  !define MUI_ABORTWARNING

;--------------------------------
;Pages

  #!insertmacro MUI_PAGE_LICENSE "License.txt"
  !insertmacro MUI_PAGE_DIRECTORY
  !insertmacro MUI_PAGE_INSTFILES
  !insertmacro MUI_PAGE_FINISH
  
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES
  !insertmacro MUI_UNPAGE_FINISH
  
;--------------------------------
;Languages
 
  !insertmacro MUI_LANGUAGE "English"

;--------------------------------
;Reserve Files
  
  ;These files should be inserted before other files in the data block
  ;Keep these lines before any File command
  ;Only for solid compression (by default, solid compression is enabled for BZIP2 and LZMA)
  
  !insertmacro MUI_RESERVEFILE_LANGDLL

;--------------------------------
;Installer Sections

Section
  !ifndef WIN64
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\App Paths\7zFMn.exe"
  !endif

  # delete old unwanted files
  Delete $INSTDIR\7zFMn.exe
  Delete $INSTDIR\7zgn.exe
  Delete $INSTDIR\7zn.exe
  Delete $INSTDIR\7zan.exe
  Delete $INSTDIR\7zC.sfx
  Delete $INSTDIR\7-zipn.dll
  Delete $INSTDIR\7zipDoc.txt
  Delete $INSTDIR\file_id.diz

  Delete $INSTDIR\Codecs\7zAES.dll
  Delete $INSTDIR\Codecs\AES.dll
  Delete $INSTDIR\Codecs\Branch.dll
  Delete $INSTDIR\Codecs\BZip2.dll
  Delete $INSTDIR\Codecs\Copy.dll
  Delete $INSTDIR\Codecs\Deflate.dll
  Delete $INSTDIR\Codecs\Implode.dll
  Delete $INSTDIR\Codecs\LZMA.dll
  Delete $INSTDIR\Codecs\PPMD.dll
  Delete $INSTDIR\Codecs\Rar29.dll
  Delete $INSTDIR\Codecs\Swap.dll

  RMDir $INSTDIR\Codecs

  Delete $INSTDIR\Formats\7z.dll
  Delete $INSTDIR\Formats\arj.dll
  Delete $INSTDIR\Formats\bz2.dll
  Delete $INSTDIR\Formats\cab.dll
  Delete $INSTDIR\Formats\chm.dll
  Delete $INSTDIR\Formats\cpio.dll
  Delete $INSTDIR\Formats\deb.dll
  Delete $INSTDIR\Formats\gz.dll
  Delete $INSTDIR\Formats\iso.dll
  Delete $INSTDIR\Formats\lzh.dll
  Delete $INSTDIR\Formats\nsis.dll
  Delete $INSTDIR\Formats\rar.dll
  Delete $INSTDIR\Formats\rpm.dll
  Delete $INSTDIR\Formats\split.dll
  Delete $INSTDIR\Formats\tar.dll
  Delete $INSTDIR\Formats\z.dll
  Delete $INSTDIR\Formats\zip.dll

  RMDir $INSTDIR\Formats

  Delete $INSTDIR\Lang\no.txt

  # install files
  SetOutPath "$INSTDIR"

  #Do not need any of these  (Rem UnZipper)
  #File descript.ion
  #File History.txt
  #File License.txt
  #File readme.txt

  # File 7-zip.dll
  # File 7-zipn.dll
  File UnZipper.exe
  File UnZipper.exe.manifest
  # File 7z.exe
  File UnZipperG.exe
  File 7z.dll
  File UnZipper.dll

  # Removed for UnZipper
  # File 7z.sfx
  # File 7zCon.sfx
  # File 7-zip.chm


  SetOutPath $INSTDIR\Lang


  SetOutPath $INSTDIR

  # delete "current user" menu items

  Delete "$SMPROGRAMS\UnZipper\${FM_LINK}"
  RMDir  "$SMPROGRAMS\UnZipper"

  # set "all users" mode

  SetShellVarContext all

  !insertmacro InstallLib DLL NOTSHARED REBOOT_NOTPROTECTED UnZipper.dll $INSTDIR\UnZipper.dll $INSTDIR

  ClearErrors

  # create start menu icons
  SetOutPath $INSTDIR # working directory
  CreateDirectory $SMPROGRAMS\UnZipper

  CreateShortcut "$SMPROGRAMS\UnZipper\${FM_LINK}" $INSTDIR\UnZipper.exe

  IfErrors 0 noScErrors

  SetShellVarContext current

  CreateDirectory $SMPROGRAMS\UnZipper
  CreateShortcut "$SMPROGRAMS\UnZipper\${FM_LINK}" $INSTDIR\UnZipper.exe

  noScErrors:

  # store install folder
  WriteRegStr HKLM "Software\UnZipper" "Path" $INSTDIR
  WriteRegStr HKCU "Software\UnZipper" "Path" $INSTDIR

  # write reg entries
  WriteRegStr HKCR "CLSID\${CLSID_CONTEXT_MENU}" "" "UnZipper Shell Extension"
  WriteRegStr HKCR "CLSID\${CLSID_CONTEXT_MENU}\InprocServer32" "" "$INSTDIR\UnZipper.dll"
  WriteRegStr HKCR "CLSID\${CLSID_CONTEXT_MENU}\InprocServer32" "ThreadingModel" "Apartment"


  WriteRegStr HKCR "*\shellex\ContextMenuHandlers\UnZipper" "" "${CLSID_CONTEXT_MENU}"
  WriteRegStr HKCR "Directory\shellex\ContextMenuHandlers\UnZipper" "" "${CLSID_CONTEXT_MENU}"
;  WriteRegStr HKCR "Folder\shellex\ContextMenuHandlers\UnZipper" "" "${CLSID_CONTEXT_MENU}"

  WriteRegStr HKCR "Directory\shellex\DragDropHandlers\UnZipper" "" "${CLSID_CONTEXT_MENU}"
  WriteRegStr HKCR "Drive\shellex\DragDropHandlers\UnZipper" "" "${CLSID_CONTEXT_MENU}"

  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Shell Extensions\Approved" "${CLSID_CONTEXT_MENU}" "UnZipper Shell Extension"
  
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\App Paths\UnZipper.exe" "" "$INSTDIR\UnZipper.exe"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\App Paths\UnZipper.exe" "Path" "$INSTDIR"

  # create uninstaller
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\UnZipper" "DisplayName" "${NAME_FULL}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\UnZipper" "DisplayVersion" "${VERSION_MAJOR}.${VERSION_MINOR}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\UnZipper" "Publisher" "TightRope Interactive"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\UnZipper" "UninstallString" '"$INSTDIR\Uninstall.exe"'
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\UnZipper" "NoModify" 1
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\UnZipper" "NoRepair" 1
  WriteUninstaller $INSTDIR\Uninstall.exe

  DeleteRegValue HKCR "CLSID\${CLSID_CONTEXT_MENU}\InprocServer32" "InprocServer32"

  !ifdef WIN64
  ExecWait 'regsvr32 /s "$INSTDIR\UnZipper.dll"'
  !endif

SectionEnd
 

;--------------------------------
;Installer Functions

/*
Function .onInit

  !insertmacro MUI_LANGDLL_DISPLAY

FunctionEnd
*/

;--------------------------------
;Uninstaller Section

Section "Uninstall"

  ExecWait 'regsvr32 /u /s "$INSTDIR\UnZipper.dll"'

  # delete files


  Delete /REBOOTOK $INSTDIR\UnZipper.dll
  Delete $INSTDIR\UnZipper.exe
  Delete $INSTDIR\UnZipper.exe.manifest
  Delete $INSTDIR\UnZipperG.exe



  Delete $INSTDIR\7z.dll

  Delete $INSTDIR\Uninstall.exe

  RMDir $INSTDIR

  # delete start menu entires

  SetShellVarContext all

  # ClearErrors

  Delete "$SMPROGRAMS\UnZipper\${FM_LINK}"
  RMDir  "$SMPROGRAMS\UnZipper\Lang"
  RMDir  "$SMPROGRAMS\UnZipper"

  # IfErrors 0 noScErrors

  SetShellVarContext current

  Delete "$SMPROGRAMS\UnZipper\${FM_LINK}"
  RMDir  "$SMPROGRAMS\UnZipper"

  # noScErrors:


  # delete registry entries

  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\UnZipper"
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\App Paths\UnZipper.exe"

  DeleteRegKey HKLM "Software\UnZipper"
  DeleteRegKey HKCU "Software\UnZipper"

  DeleteRegKey HKCR "CLSID\${CLSID_CONTEXT_MENU}"

  DeleteRegKey HKCR "*\shellex\ContextMenuHandlers\UnZipper"
  DeleteRegKey HKCR "Directory\shellex\ContextMenuHandlers\UnZipper"
  DeleteRegKey HKCR "Folder\shellex\ContextMenuHandlers\UnZipper"

  DeleteRegKey HKCR "Directory\shellex\DragDropHandlers\UnZipper"
  DeleteRegKey HKCR "Drive\shellex\DragDropHandlers\UnZipper"

  DeleteRegValue HKLM "Software\Microsoft\Windows\CurrentVersion\Shell Extensions\Approved" "${CLSID_CONTEXT_MENU}"

  DeleteRegKey HKCR "UnZipper.001"
  DeleteRegKey HKCR "UnZipper.7z"
  DeleteRegKey HKCR "UnZipper.arj"
  DeleteRegKey HKCR "UnZipper.bz2"
  DeleteRegKey HKCR "UnZipper.bzip2"
  DeleteRegKey HKCR "UnZipper.tbz"
  DeleteRegKey HKCR "UnZipper.tbz2"
  DeleteRegKey HKCR "UnZipper.cab"
  DeleteRegKey HKCR "UnZipper.cpio"
  DeleteRegKey HKCR "UnZipper.deb"
  DeleteRegKey HKCR "UnZipper.dmg"
  DeleteRegKey HKCR "UnZipper.gz"
  DeleteRegKey HKCR "UnZipper.gzip"
  DeleteRegKey HKCR "UnZipper.hfs"
  DeleteRegKey HKCR "UnZipper.iso"
  DeleteRegKey HKCR "UnZipper.lha"
  DeleteRegKey HKCR "UnZipper.lzh"
  DeleteRegKey HKCR "UnZipper.lzma"
  DeleteRegKey HKCR "UnZipper.rar"
  DeleteRegKey HKCR "UnZipper.rpm"
  DeleteRegKey HKCR "UnZipper.split"
  DeleteRegKey HKCR "UnZipper.swm"
  DeleteRegKey HKCR "UnZipper.tar"
  DeleteRegKey HKCR "UnZipper.taz"
  DeleteRegKey HKCR "UnZipper.tgz"
  DeleteRegKey HKCR "UnZipper.tpz"
  DeleteRegKey HKCR "UnZipper.wim"
  DeleteRegKey HKCR "UnZipper.xar"
  DeleteRegKey HKCR "UnZipper.z"
  DeleteRegKey HKCR "UnZipper.zip"

SectionEnd
